@@ -3,7 +3,7 @@
 /**
  * Driver for holidays in Spain
  *
- * PHP Version 4
+ * PHP Version 5
  *
  * Copyright (c) 1997-2011 The PHP Group
  *
@@ -247,7 +247,7 @@ class Date_Holidays_Driver_Spain extends Date_Holidays_Driver
      */
     function getISO3166Codes()
     {
-        return array('es');
+        return array('es', 'esp');
     }
 }
 ?>
